/*
 SPDX-License-Identifier: GPL-3.0-or-later
 myMPD (c) 2018-2025 Juergen Mang <mail@jcgames.de>
 https://github.com/jcorporation/mympd
*/

/*! \file
 * \brief MPD feature detection
 */

#ifndef MYMPD_MPD_CLIENT_FEATURES_H
#define MYMPD_MPD_CLIENT_FEATURES_H

#include "src/lib/config/mympd_state.h"

void mympd_client_mpd_features(struct t_mympd_state *mympd_state, struct t_partition_state *partition_state);
#endif
